=========
Changelog
=========

0.2.2 - 13 July 2012
~~~~~~~~~~~~~~~~~~~~

Fixes a bug with applying absolute-discount benefits

0.2.1 - 09 July 2012
~~~~~~~~~~~~~~~~~~~~

Mainly small bug-fixes to templates and javascript.  

0.2 - 01 June 2012
~~~~~~~~~~~~~~~~~~

Many components have been rewritten since 0.1 - Oscar is much more of a complete
package now.  New features include:

* Dashboard for managing catalogue, offers, stock, vouchers and more.  This includes
  statistics pages to track performance.

* Sample templates, CSS and JS to get a shop up and running in a minutes.  

* Updated documentation.

* Reworking of shipping methods.

* Automatic up-selling on the basket page.  We now inform the user if they
  partially quanlify for an offer.

The documentation still needs more work which we'll do over the next week or
two.

0.1
~~~

* Initial release - used in production by two major applications at Tangent but
  still quite rough around the edges.  Many features were implemented directly
  in the applications rather than using a feature from oscar.

* Docs are a bit stale and need updating in 0.2

